==> jc-1.4.0.tar.gz: javax/swing/Spring__24MaxSpring.h <==
// final class javax.swing.Spring$MaxSpring

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 52c68a5c6f02978c javax_swing_Spring
// @dep_class 7b7fab7bfdaf65c7 javax_swing_Spring__24MaxSpring

// header file dependencies
// @dep_header javax_swing_Spring

#include "javax/swing/Spring.h"

#ifndef _JC_javax_swing_Spring__24MaxSpring_H_
#define _JC_javax_swing_Spring__24MaxSpring_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Spring$object;

// Typedefs
typedef struct _jc_javax_swing_Spring__24MaxSpring$sub_refs	_jc_javax_swing_Spring__24MaxSpring$sub_refs;
typedef struct _jc_javax_swing_Spring__24MaxSpring$sub_nonrefs	_jc_javax_swing_Spring__24MaxSpring$sub_nonrefs;
typedef struct _jc_javax_swing_Spring__24MaxSpring$refs	_jc_javax_swing_Spring__24MaxSpring$refs;
typedef struct _jc_javax_swing_Spring__24MaxSpring$nonrefs	_jc_javax_swing_Spring__24MaxSpring$nonrefs;
typedef struct _jc_javax_swing_Spring__24MaxSpring$object	_jc_javax_swing_Spring__24MaxSpring$object;

typedef const struct _jc_javax_swing_Spring__24MaxSpring$vmethods	_jc_javax_swing_Spring__24MaxSpring$vmethods;
typedef const struct _jc_javax_swing_Spring__24MaxSpring$vtable	_jc_javax_swing_Spring__24MaxSpring$vtable;
typedef const struct _jc_javax_swing_Spring__24MaxSpring$vtype	_jc_javax_swing_Spring__24MaxSpring$vtype;

// Constructors
extern void _jc_javax_swing_Spring__24MaxSpring$method$_init$5faa5ccef74e86ad(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *, struct _jc_javax_swing_Spring$object *, struct _jc_javax_swing_Spring$object *);

// Virtual methods
extern jint _jc_javax_swing_Spring__24MaxSpring$method$getMaximumValue$dd51e3d6fecde040(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *);
extern jint _jc_javax_swing_Spring__24MaxSpring$method$getMinimumValue$a7d66b63a1df3c72(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *);
extern jint _jc_javax_swing_Spring__24MaxSpring$method$getPreferredValue$c216b16eb60a1689(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *);
extern jint _jc_javax_swing_Spring__24MaxSpring$method$getValue$245714dca3f59de3(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *);
extern void _jc_javax_swing_Spring__24MaxSpring$method$setValue$e6840ec6b97bf5b1(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Spring__24MaxSpring$method_info$getMaximumValue$dd51e3d6fecde040;
extern _jc_method _jc_javax_swing_Spring__24MaxSpring$method_info$getMinimumValue$a7d66b63a1df3c72;
extern _jc_method _jc_javax_swing_Spring__24MaxSpring$method_info$getPreferredValue$c216b16eb60a1689;
extern _jc_method _jc_javax_swing_Spring__24MaxSpring$method_info$getValue$245714dca3f59de3;
extern _jc_method _jc_javax_swing_Spring__24MaxSpring$method_info$setValue$e6840ec6b97bf5b1;

// Virtual methods structure
struct _jc_javax_swing_Spring__24MaxSpring$vmethods {
	jint	(*getMaximumValue$dd51e3d6fecde040)(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *);
	jint	(*getMinimumValue$a7d66b63a1df3c72)(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *);
	jint	(*getPreferredValue$c216b16eb60a1689)(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *);
	jint	(*getValue$245714dca3f59de3)(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *);
	void	(*setValue$e6840ec6b97bf5b1)(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *, jint);
};

// Vtable
struct _jc_javax_swing_Spring__24MaxSpring$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_Spring$vmethods	javax_swing_Spring;
	_jc_javax_swing_Spring__24MaxSpring$vmethods	javax_swing_Spring__24MaxSpring;
};

// Vtype
struct _jc_javax_swing_Spring__24MaxSpring$vtype {
	_jc_type			type;
	_jc_javax_swing_Spring__24MaxSpring$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Spring__24MaxSpring$sub_refs {
	struct _jc_javax_swing_Spring$object	*s1;
	struct _jc_javax_swing_Spring$object	*s2;
};

// Reference instance fields (object)
struct _jc_javax_swing_Spring__24MaxSpring$refs {
    _jc_javax_swing_Spring__24MaxSpring$sub_refs	javax_swing_Spring__24MaxSpring;
    _jc_javax_swing_Spring$sub_refs	javax_swing_Spring;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Spring__24MaxSpring$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Spring__24MaxSpring$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_Spring$sub_nonrefs	javax_swing_Spring;
    _jc_javax_swing_Spring__24MaxSpring$sub_nonrefs	javax_swing_Spring__24MaxSpring;
};

// Object instance structure
struct _jc_javax_swing_Spring__24MaxSpring$object {
	_jc_javax_swing_Spring__24MaxSpring$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Spring__24MaxSpring$vtype	*vtype;
	_jc_javax_swing_Spring__24MaxSpring$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Spring__24MaxSpring$vtype _jc_javax_swing_Spring__24MaxSpring$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Spring__24MaxSpring, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Spring__24MaxSpring$class_object;

#endif	/* _JC_javax_swing_Spring__24MaxSpring_H_ */

==> jc-1.4.6.tar.gz: javax/swing/Spring__24MaxSpring.h <==
// final class javax.swing.Spring$MaxSpring

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 52c68a5c6f02978c javax_swing_Spring
// @dep_class 7b7fab7bfdaf65c7 javax_swing_Spring__24MaxSpring

// header file dependencies
// @dep_header javax_swing_Spring

#include "javax/swing/Spring.h"

#ifndef _JC_javax_swing_Spring__24MaxSpring_H_
#define _JC_javax_swing_Spring__24MaxSpring_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Spring$object;

// Typedefs
typedef struct _jc_javax_swing_Spring__24MaxSpring$sub_refs	_jc_javax_swing_Spring__24MaxSpring$sub_refs;
typedef struct _jc_javax_swing_Spring__24MaxSpring$sub_nonrefs	_jc_javax_swing_Spring__24MaxSpring$sub_nonrefs;
typedef struct _jc_javax_swing_Spring__24MaxSpring$refs	_jc_javax_swing_Spring__24MaxSpring$refs;
typedef struct _jc_javax_swing_Spring__24MaxSpring$nonrefs	_jc_javax_swing_Spring__24MaxSpring$nonrefs;
typedef struct _jc_javax_swing_Spring__24MaxSpring$object	_jc_javax_swing_Spring__24MaxSpring$object;

typedef const struct _jc_javax_swing_Spring__24MaxSpring$vmethods	_jc_javax_swing_Spring__24MaxSpring$vmethods;
typedef const struct _jc_javax_swing_Spring__24MaxSpring$vtable	_jc_javax_swing_Spring__24MaxSpring$vtable;
typedef const struct _jc_javax_swing_Spring__24MaxSpring$vtype	_jc_javax_swing_Spring__24MaxSpring$vtype;

// Constructors
extern void _jc_javax_swing_Spring__24MaxSpring$method$_init$5faa5ccef74e86ad(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *, struct _jc_javax_swing_Spring$object *, struct _jc_javax_swing_Spring$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_Spring__24MaxSpring$method$getMaximumValue$dd51e3d6fecde040(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_Spring__24MaxSpring$method$getMinimumValue$a7d66b63a1df3c72(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_Spring__24MaxSpring$method$getPreferredValue$c216b16eb60a1689(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_Spring__24MaxSpring$method$getValue$245714dca3f59de3(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_Spring__24MaxSpring$method$setValue$e6840ec6b97bf5b1(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Spring__24MaxSpring$method_info$getMaximumValue$dd51e3d6fecde040;
extern _jc_method _jc_javax_swing_Spring__24MaxSpring$method_info$getMinimumValue$a7d66b63a1df3c72;
extern _jc_method _jc_javax_swing_Spring__24MaxSpring$method_info$getPreferredValue$c216b16eb60a1689;
extern _jc_method _jc_javax_swing_Spring__24MaxSpring$method_info$getValue$245714dca3f59de3;
extern _jc_method _jc_javax_swing_Spring__24MaxSpring$method_info$setValue$e6840ec6b97bf5b1;

// Virtual methods structure
struct _jc_javax_swing_Spring__24MaxSpring$vmethods {
	jint	(*getMaximumValue$dd51e3d6fecde040)(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *) _JC_JCNI_ATTR;
	jint	(*getMinimumValue$a7d66b63a1df3c72)(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *) _JC_JCNI_ATTR;
	jint	(*getPreferredValue$c216b16eb60a1689)(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *) _JC_JCNI_ATTR;
	jint	(*getValue$245714dca3f59de3)(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *) _JC_JCNI_ATTR;
	void	(*setValue$e6840ec6b97bf5b1)(_jc_env *, struct _jc_javax_swing_Spring__24MaxSpring$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_Spring__24MaxSpring$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_Spring$vmethods	javax_swing_Spring;
	_jc_javax_swing_Spring__24MaxSpring$vmethods	javax_swing_Spring__24MaxSpring;
};

// Vtype
struct _jc_javax_swing_Spring__24MaxSpring$vtype {
	_jc_type			type;
	_jc_javax_swing_Spring__24MaxSpring$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Spring__24MaxSpring$sub_refs {
	struct _jc_javax_swing_Spring$object	*s1;
	struct _jc_javax_swing_Spring$object	*s2;
};

// Reference instance fields (object)
struct _jc_javax_swing_Spring__24MaxSpring$refs {
    _jc_javax_swing_Spring__24MaxSpring$sub_refs	javax_swing_Spring__24MaxSpring;
    _jc_javax_swing_Spring$sub_refs	javax_swing_Spring;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Spring__24MaxSpring$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Spring__24MaxSpring$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_Spring$sub_nonrefs	javax_swing_Spring;
    _jc_javax_swing_Spring__24MaxSpring$sub_nonrefs	javax_swing_Spring__24MaxSpring;
};

// Object instance structure
struct _jc_javax_swing_Spring__24MaxSpring$object {
	_jc_javax_swing_Spring__24MaxSpring$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Spring__24MaxSpring$vtype	*vtype;
	_jc_javax_swing_Spring__24MaxSpring$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Spring__24MaxSpring$vtype _jc_javax_swing_Spring__24MaxSpring$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Spring__24MaxSpring, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Spring__24MaxSpring$class_object;

#endif	/* _JC_javax_swing_Spring__24MaxSpring_H_ */
